/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.salary.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 统计-全年一次性奖金
 *
 * @author huyc
 * @date 2022-08-05 11:40:15
 */
@Data
public class TStatisticsAnnualBonusImportVo extends RowIndex implements Serializable {

	/**
	 * 员工姓名
	 */
	@Length(max = 50, message = "员工姓名 不能超过50 个字符")
	@NotNull(message = "员工姓名不可为空")
	@ExcelAttribute(name = "员工姓名", maxLength = 50, isNotEmpty = true)
	@Schema(description = "员工姓名")
	@ExcelProperty("员工姓名")
	private String empName;

	/**
	 * 员工身份证号
	 */
	@Length(max = 25, message = "身份证号不能超过25个字符")
	@NotNull(message = "身份证号不可为空")
	@ExcelAttribute(name = "身份证号", maxLength = 25, isNotEmpty = true)
	@Schema(description = "身份证号")
	@ExcelProperty("身份证号")
	private String empIdcard;

	/**
	 * 年终奖
	 */
	@ExcelAttribute(name = "待发年终奖", isNotEmpty = true)
	@NotNull(message = "待发年终奖不可为空")
	@Schema(description = "待发年终奖")
	@ExcelProperty("待发年终奖")
	private BigDecimal preAnnualBonus;

	/**
	 * 年终奖单独税
	 */
	@ExcelAttribute(name = "待发12月工资", isNotEmpty = true)
	@NotNull(message = "待发12月工资不可为空")
	@Schema(description = "待发12月工资")
	@ExcelProperty("待发12月工资")
	private BigDecimal preDecSalary;

	/**
	 * 年终奖单独扣税12月税费
	 */
	@ExcelAttribute(name = "年终奖单独扣税12月税费")
	@Schema(description = "年终奖单独扣税12月税费")
	@ExcelProperty("年终奖单独扣税12月税费")
	private BigDecimal onlyTax;

	/**
	 * 年终奖合并扣税12月税费
	 */
	@ExcelAttribute(name = "年终奖合并扣税12月税费")
	@Schema(description = "年终奖合并扣税12月税费")
	@ExcelProperty("年终奖合并扣税12月税费")
	private BigDecimal sumTax;

	/**
	 * 最优方案-年终奖
	 */
	@ExcelAttribute(name = "最优方案-年终奖")
	@Schema(description = "最优方案-年终奖")
	@ExcelProperty("最优方案-年终奖")
	private BigDecimal bestSolutionTax;

	/**
	 * 最优方案-12月扣税
	 */
	@ExcelAttribute(name = "最优方案-12月扣税")
	@Schema(description = "最优方案-12月扣税")
	@ExcelProperty("最优方案-12月扣税")
	private BigDecimal bestSolutionDecTax;
}
