/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.SysMessageSalary;
import com.yifu.cloud.plus.v1.yifu.salary.service.SysMessageSalaryService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.SysMessageSalarySearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 最低工资提醒-每月更新一次
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/sysmessagesalary")
@Tag(name = "最低工资提醒-每月更新一次管理")
public class SysMessageSalaryController {

	private final SysMessageSalaryService sysMessageSalaryService;


	/**
	 * 简单分页查询
	 *
	 * @param page             分页对象
	 * @param sysMessageSalary 最低工资提醒-每月更新一次
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<SysMessageSalary>> getSysMessageSalaryPage(Page<SysMessageSalary> page, SysMessageSalarySearchVo sysMessageSalary) {
		return new R<>(sysMessageSalaryService.getSysMessageSalaryPage(page, sysMessageSalary));
	}

	/**
	 * 不分页查询
	 *
	 * @param sysMessageSalary 最低工资提醒-每月更新一次
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_sysmessagesalary_get')" )
	public R<List<SysMessageSalary>> getSysMessageSalaryNoPage(@RequestBody SysMessageSalarySearchVo sysMessageSalary) {
		return R.ok(sysMessageSalaryService.noPageDiy(sysMessageSalary));
	}

	/**
	 * 通过id查询最低工资提醒-每月更新一次
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_sysmessagesalary_get')")
	@GetMapping("/{id}")
	public R<SysMessageSalary> getById(@PathVariable("id") String id) {
		return R.ok(sysMessageSalaryService.getById(id));
	}

	/**
	 * 新增最低工资提醒-每月更新一次
	 *
	 * @param sysMessageSalary 最低工资提醒-每月更新一次
	 * @return R
	 */
	@Operation(summary = "新增最低工资提醒-每月更新一次", description = "新增最低工资提醒-每月更新一次：hasPermission('salary_sysmessagesalary_add')")
	@SysLog("新增最低工资提醒-每月更新一次")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_sysmessagesalary_add')")
	public R<Boolean> save(@RequestBody SysMessageSalary sysMessageSalary) {
		return R.ok(sysMessageSalaryService.save(sysMessageSalary));
	}

	/**
	 * 修改最低工资提醒-每月更新一次
	 *
	 * @param sysMessageSalary 最低工资提醒-每月更新一次
	 * @return R
	 */
	@Operation(summary = "修改最低工资提醒-每月更新一次", description = "修改最低工资提醒-每月更新一次：hasPermission('salary_sysmessagesalary_edit')")
	@SysLog("修改最低工资提醒-每月更新一次")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_sysmessagesalary_edit')")
	public R<Boolean> updateById(@RequestBody SysMessageSalary sysMessageSalary) {
		return R.ok(sysMessageSalaryService.updateById(sysMessageSalary));
	}

	/**
	 * 通过id删除最低工资提醒-每月更新一次
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除最低工资提醒-每月更新一次", description = "通过id删除最低工资提醒-每月更新一次：hasPermission('salary_sysmessagesalary_del')")
	@SysLog("通过id删除最低工资提醒-每月更新一次")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_sysmessagesalary_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(sysMessageSalaryService.removeById(id));
	}

}
