/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.ErrorMessage;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TSalaryAccount;
import com.yifu.cloud.plus.v1.yifu.salary.service.TSalaryAccountService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TSalaryAccountSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.SneakyThrows;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;


/**
 * 工资报账主表（工资条）
 *
 * @author hgw
 * @date 2022-08-05 11:40:14
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tsalaryaccount")
@Tag(name = "工资报账主表（工资条）管理")
public class TSalaryAccountController {

	private final TSalaryAccountService tSalaryAccountService;


	/**
	 * 简单分页查询
	 *
	 * @param page           分页对象
	 * @param tSalaryAccount 工资报账主表（工资条）
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TSalaryAccount>> getTSalaryAccountPage(Page<TSalaryAccount> page, TSalaryAccountSearchVo tSalaryAccount) {
		return new R<>(tSalaryAccountService.getTSalaryAccountPage(page, tSalaryAccount));
	}

	/**
	 * 不分页查询
	 *
	 * @param tSalaryAccount 工资报账主表（工资条）
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	//@PreAuthorize("@pms.hasPermission('salary_tsalaryaccount_get')" )
	public R<List<TSalaryAccount>> getTSalaryAccountNoPage(@RequestBody TSalaryAccountSearchVo tSalaryAccount) {
		return R.ok(tSalaryAccountService.noPageDiy(tSalaryAccount));
	}

	/**
	 * 通过id查询工资报账主表（工资条）
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询：hasPermission('salary_tsalaryaccount_get')")
	@GetMapping("/{id}")
	public R<TSalaryAccount> getById(@PathVariable("id") String id) {
		return R.ok(tSalaryAccountService.getById(id));
	}

	/**
	 * 新增工资报账主表（工资条）
	 *
	 * @param tSalaryAccount 工资报账主表（工资条）
	 * @return R
	 */
	@Operation(summary = "新增工资报账主表（工资条）", description = "新增工资报账主表（工资条）：hasPermission('salary_tsalaryaccount_add')")
	@SysLog("新增工资报账主表（工资条）")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryaccount_add')")
	public R<Boolean> save(@RequestBody TSalaryAccount tSalaryAccount) {
		return R.ok(tSalaryAccountService.save(tSalaryAccount));
	}

	/**
	 * 修改工资报账主表（工资条）
	 *
	 * @param tSalaryAccount 工资报账主表（工资条）
	 * @return R
	 */
	@Operation(summary = "修改工资报账主表（工资条）", description = "修改工资报账主表（工资条）：hasPermission('salary_tsalaryaccount_edit')")
	@SysLog("修改工资报账主表（工资条）")
	@PutMapping
	@PreAuthorize("@pms.hasPermission('salary_tsalaryaccount_edit')")
	public R<Boolean> updateById(@RequestBody TSalaryAccount tSalaryAccount) {
		return R.ok(tSalaryAccountService.updateById(tSalaryAccount));
	}

	/**
	 * 通过id删除工资报账主表（工资条）
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除工资报账主表（工资条）", description = "通过id删除工资报账主表（工资条）：hasPermission('salary_tsalaryaccount_del')")
	@SysLog("通过id删除工资报账主表（工资条）")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tsalaryaccount_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tSalaryAccountService.removeById(id));
	}

	/**
	 * 工资报账主表（工资条） 批量导出
	 *
	 * @author hgw
	 * @date 2022-08-05 11:40:14
	 **/
	@Operation(description = "导出工资报账主表（工资条） hasPermission('salary_tsalaryaccount-export')")
	@PostMapping("/export")
	@PreAuthorize("@pms.hasPermission('salary_tsalaryaccount-export')")
	public void export(HttpServletResponse response, @RequestBody TSalaryAccountSearchVo searchVo) {
		tSalaryAccountService.listExport(response, searchVo);
	}
}
