/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.salary.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.*;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.yifu.salary.entity.TStatisticsAnnualBonus;
import com.yifu.cloud.plus.v1.yifu.salary.service.TStatisticsAnnualBonusService;
import com.yifu.cloud.plus.v1.yifu.salary.vo.TStatisticsAnnualBonusSearchVo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;


/**
 * 统计-全年一次性奖金
 *
 * @author hgw
 * @date 2022-08-05 11:40:15
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/tstatisticsannualbonus")
@Tag(name = "统计-全年一次性奖金管理")
@Slf4j
public class TStatisticsAnnualBonusController {

	private final TStatisticsAnnualBonusService tStatisticsAnnualBonusService;

	/**
	 * 简单分页查询
	 *
	 * @param page                   分页对象
	 * @param tStatisticsAnnualBonus 统计-全年一次性奖金
	 * @return
	 */
	@Operation(description = "简单分页查询")
	@GetMapping("/page")
	public R<IPage<TStatisticsAnnualBonus>> getTStatisticsAnnualBonusPage(Page<TStatisticsAnnualBonus> page, TStatisticsAnnualBonusSearchVo tStatisticsAnnualBonus) {
		return new R<>(tStatisticsAnnualBonusService.getTStatisticsAnnualBonusPage(page, tStatisticsAnnualBonus));
	}

	/**
	 * 不分页查询
	 *
	 * @param tStatisticsAnnualBonus 统计-全年一次性奖金
	 * @return
	 */
	@Operation(summary = "不分页查询", description = "不分页查询")
	@PostMapping("/noPage")
	public R<List<TStatisticsAnnualBonus>> getTStatisticsAnnualBonusNoPage(@RequestBody TStatisticsAnnualBonusSearchVo tStatisticsAnnualBonus) {
		return R.ok(tStatisticsAnnualBonusService.noPageDiy(tStatisticsAnnualBonus));
	}

	/**
	 * 通过id查询统计-全年一次性奖金
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id查询", description = "通过id查询")
	@GetMapping("/{id}")
	public R<TStatisticsAnnualBonus> getById(@PathVariable("id") String id) {
		return R.ok(tStatisticsAnnualBonusService.getById(id));
	}

	/**
	 * 新增统计-全年一次性奖金
	 *
	 * @param tStatisticsAnnualBonus 统计-全年一次性奖金
	 * @return R
	 */
	@Operation(summary = "新增统计-全年一次性奖金", description = "新增统计-全年一次性奖金：hasPermission('salary_tstatisticsannualbonus_add')")
	@SysLog("新增统计-全年一次性奖金")
	@PostMapping
	@PreAuthorize("@pms.hasPermission('salary_tstatisticsannualbonus_add')")
	public R<Boolean> save(@RequestBody TStatisticsAnnualBonus tStatisticsAnnualBonus) {
		return R.ok(tStatisticsAnnualBonusService.save(tStatisticsAnnualBonus));
	}

	/**
	 * 通过id删除统计-全年一次性奖金
	 *
	 * @param id id
	 * @return R
	 */
	@Operation(summary = "通过id删除统计-全年一次性奖金", description = "通过id删除统计-全年一次性奖金：hasPermission('salary_tstatisticsannualbonus_del')")
	@SysLog("通过id删除统计-全年一次性奖金")
	@DeleteMapping("/{id}")
	@PreAuthorize("@pms.hasPermission('salary_tstatisticsannualbonus_del')")
	public R<Boolean> removeById(@PathVariable String id) {
		return R.ok(tStatisticsAnnualBonusService.removeById(id));
	}


	/**
	 * 统计-全年一次性奖金 批量导出
	 *
	 * @author hgw
	 * @date 2022-08-05 11:40:15
	 **/
	@Operation(description = "导出统计-全年一次性奖金 hasPermission('salary_tstatisticsannualbonus-export')")
	@PostMapping("/export")
	@PreAuthorize("@pms.hasPermission('salary_tstatisticsannualbonus-export')")
	public void export(HttpServletResponse response, @RequestBody TStatisticsAnnualBonusSearchVo searchVo) {
		tStatisticsAnnualBonusService.listExport(response, searchVo);
	}


	/**
	 * 年终奖分配方案导入导出
	 *
	 * @author huyc
	 * @date 2022-08-08
	 **/
	@Operation(description = "年终奖分配方案导入导出 hasPermission('salary_tstatisticsannualbonus_import')")
	@PostMapping("/bestSolutionExport")
	@PreAuthorize("@pms.hasPermission('salary_tstatisticsannualbonus_import')")
	public R<List<ErrorMessage>> bestSolutionExport(@RequestBody MultipartFile file
			, HttpServletResponse response, List<String> exportFields) throws IOException {
		return tStatisticsAnnualBonusService.bestSendExport(file.getInputStream(), response, exportFields);
	}
}
